# Security Policy

To report a security issue, either report it privately
[on GitHub](https://github.com/ultrajson/ultrajson/security) (preferred) or
through the [Tidelift security contact](https://tidelift.com/security). Do not
report them on the public issue tracker.
